[Genabel-commits] r1585 - pkg/GenABEL-general/scripts

noreply at r-forge.r-project.org noreply at r-forge.r-project.org
Mon Feb 3 16:46:40 CET 2014


Author: lckarssen
Date: 2014-02-03 16:46:39 +0100 (Mon, 03 Feb 2014)
New Revision: 1585

Modified:
   pkg/GenABEL-general/scripts/makedistrib_MetABEL.sh
Log:
Add an option to suppress the --as-cran checks to the makedistrib_MetABEL.sh script.


Modified: pkg/GenABEL-general/scripts/makedistrib_MetABEL.sh
===================================================================
--- pkg/GenABEL-general/scripts/makedistrib_MetABEL.sh	2014-02-03 15:38:27 UTC (rev 1584)
+++ pkg/GenABEL-general/scripts/makedistrib_MetABEL.sh	2014-02-03 15:46:39 UTC (rev 1585)
@@ -6,8 +6,10 @@
 #
 # Command line options:
 # -n|--nocheckout: if the first command line option is keepold the previously
 # checked out source code will not be deleted and no SVN checkout will
 # be done. This is handy when trying out some of your local changes.
 
 PKG=MetABEL
 CRAN_repo='"http://cran-mirror.cs.uu.nl"'
@@ -21,11 +23,15 @@
 
 # Parse command line options
 NOCHECKOUT=false
+CRANCHECK=true
 while [ $# -gt 0 ]; do
     case $1 in
         -n | --nocheckout )
             NOCHECKOUT=true
             ;;
+        -c | --nocrancheck )
+            CRANCHECK=false
+            ;;
         -* )
             echo "$0: invalid option $1" >&2
             exit 1
@@ -89,15 +95,17 @@
     errwarn=1
 fi
 
-echo
-echo "--------------------------------------------------"
-echo "Check with --as-cran..."
-echo "--------------------------------------------------"
-R CMD check --as-cran $PKG
-if sed -e 's/feasibility ... WARNING/feasibility ... WRNNG/' \
-    -e 's/^WARNING/WRNNG/' $PKG.Rcheck/00check.log | \
-    grep -qE "NOTE|WARNING|ERROR"; then
-    errwarn=1
+if [ $CRANCHECK == true ]; then
+    echo
+    echo "--------------------------------------------------"
+    echo "Check with --as-cran..."
+    echo "--------------------------------------------------"
+    R CMD check --as-cran $PKG
+    if sed -e 's/feasibility ... WARNING/feasibility ... WRNNG/' \
+        -e 's/^WARNING/WRNNG/' $PKG.Rcheck/00check.log | \
+        grep -qE "NOTE|WARNING|ERROR"; then
+        errwarn=1
+    fi
 fi
 
 echo
@@ -6,8 +6,10 @@
 # Command line options:
 # -n|--nocheckout: if the first command line option is keepold the previously
-# checked out source code will not be deleted and no SVN checkout will
-# be done. This is handy when trying out some of your local changes.
+#   checked out source code will not be deleted and no SVN checkout will
+#   be done. This is handy when trying out some of your local changes.
+# -c|--nocrancheck: don't run R CMD check --as-cran (can save some
+#   time if you're expecting trouble)
 
 PKG=MetABEL



More information about the Genabel-commits mailing list